@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2005 Kenneth J. Pronovici.
+# Copyright (c) 2005,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,9 +25,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Official Cedar Backup Extensions
-# Revision : $Id: mysql.py 499 2005-10-30 21:24:59Z pronovic $
+# Revision : $Id: mysql.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Provides an extension to back up MySQL databases.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -94,8 +94,8 @@ from bz2 import BZ2File
 
 # Cedar Backup modules
 from CedarBackup2.xmlutil import createInputDom, addContainerNode, addStringNode, addBooleanNode
-from CedarBackup2.xmlutil import readChildren, readFirstChild, readString, readStringList, readBoolean
-from CedarBackup2.config import VALID_COLLECT_MODES, VALID_COMPRESS_MODES
+from CedarBackup2.xmlutil import readFirstChild, readString, readStringList, readBoolean
+from CedarBackup2.config import VALID_COMPRESS_MODES
 from CedarBackup2.util import resolveCommand, executeCommand
 from CedarBackup2.util import ObjectTypeList, changeOwnership
 
@@ -129,7 +129,7 @@ class MysqlConfig(object):
    @sort: __init__, __repr__, __str__, __cmp__, user, password, all, databases
    """
 
-   def __init__(self, user=None, password=None, compressMode=None, all=None, databases=None):
+   def __init__(self, user=None, password=None, compressMode=None, all=None, databases=None):  # pylint: disable-msg=W0622
       """
       Constructor for the C{MysqlConfig} class.
       
@@ -170,28 +170,28 @@ class MysqlConfig(object):
       """
       if other is None:
          return 1
-      if self._user != other._user:
-         if self._user < other._user:
+      if self.user != other.user:
+         if self.user < other.user:
             return -1
          else:
             return 1
-      if self._password != other._password:
-         if self._password < other._password:
+      if self.password != other.password:
+         if self.password < other.password:
             return -1
          else:
             return 1
-      if self._compressMode != other._compressMode:
-         if self._compressMode < other._compressMode:
+      if self.compressMode != other.compressMode:
+         if self.compressMode < other.compressMode:
             return -1
          else:
             return 1
-      if self._all != other._all:
-         if self._all < other._all:
+      if self.all != other.all:
+         if self.all < other.all:
             return -1
          else:
             return 1
-      if self._databases != other._databases:
-         if self._databases < other._databases:
+      if self.databases != other.databases:
+         if self.databases < other.databases:
             return -1
          else:
             return 1
@@ -383,8 +383,8 @@ class LocalConfig(object):
       """
       if other is None:
          return 1
-      if self._mysql != other._mysql:
-         if self._mysql < other._mysql:
+      if self.mysql != other.mysql:
+         if self.mysql < other.mysql:
             return -1
          else:
             return 1
@@ -479,6 +479,7 @@ class LocalConfig(object):
       (xmlDom, parentNode) = createInputDom(xmlData)
       self._mysql = LocalConfig._parseMysql(parentNode)
 
+   @staticmethod
    def _parseMysql(parentNode):
       """
       Parses a mysql configuration section.
@@ -510,7 +511,6 @@ class LocalConfig(object):
          mysql.all = readBoolean(section, "all")
          mysql.databases = readStringList(section, "database")
       return mysql
-   _parseMysql = staticmethod(_parseMysql)
 
 
 ########################################################################
