@@ -9,9 +9,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: image.py 657 2007-01-31 02:05:57Z pronovic $
+# Revision : $Id: image.py 998 2010-07-07 19:56:08Z pronovic $
 # Purpose  : Provides interface backwards compatibility.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -35,5 +35,5 @@ library interface.
 # Imported modules
 ########################################################################
 
-from CedarBackup2.writers.util import IsoImage
+from CedarBackup2.writers.util import IsoImage  # pylint: disable-msg=W0611
 
