@@ -9,9 +9,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: release.py 957 2010-01-10 22:54:17Z pronovic $
+# Revision : $Id: release.py 1015 2010-10-20 01:55:44Z pronovic $
 # Purpose  : Provides location to maintain release information.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -34,7 +34,7 @@ Provides location to maintain version information.
 AUTHOR      = "Kenneth J. Pronovici"
 EMAIL       = "pronovic@ieee.org"
 COPYRIGHT   = "2004-2010"
-VERSION     = "2.19.5"
-DATE        = "10 Jan 2010"
+VERSION     = "2.20.1"
+DATE        = "19 Oct 2010"
 URL         = "http://cedar-backup.sourceforge.net/"
 
