@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2004-2008 Kenneth J. Pronovici.
+# Copyright (c) 2004-2008,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # Portions copyright (c) 2001, 2002 Python Software Foundation.
@@ -28,9 +28,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: util.py 966 2010-02-23 22:29:55Z pronovic $
+# Revision : $Id: util.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Provides general-purpose utilities.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -83,7 +83,8 @@ import os
 import re
 import time
 import logging
-import string
+import string  # pylint: disable-msg=W0402
+from subprocess import Popen, STDOUT, PIPE
 
 from CedarBackup2.release import VERSION, DATE
 
@@ -94,16 +95,6 @@ try:
 except ImportError:
    _UID_GID_AVAILABLE = False   
 
-try:
-   from subprocess import Popen
-   _PIPE_IMPLEMENTATION = "subprocess.Popen"
-except ImportError:
-   try:
-      from popen2 import Popen4
-      _PIPE_IMPLEMENTATION = "popen2.Popen4"
-   except ImportError:
-      raise ImportError("Unable to import either subprocess.Popen or popen2.Popen4 for use by Pipe class.")
-
 
 ########################################################################
 # Module-wide constants and variables
@@ -341,6 +332,7 @@ class ObjectTypeList(UnorderedList):
       @param objectType: Type that the list elements must match.
       @param objectName: Short string containing the "name" of the type.
       """
+      super(ObjectTypeList, self).__init__()
       self.objectType = objectType
       self.objectName = objectName
 
@@ -406,6 +398,7 @@ class RestrictedContentList(UnorderedList):
       @param valuesDescr: Short string describing list of values.
       @param prefix: Prefix to use in error messages (None results in prefix "Item")
       """
+      super(RestrictedContentList, self).__init__()
       self.prefix = "Item"
       if prefix is not None: self.prefix = prefix
       self.valuesList = valuesList
@@ -470,6 +463,7 @@ class RegexMatchList(UnorderedList):
       @param emptyAllowed: Indicates whether empty or None values are allowed.
       @param prefix: Prefix to use in error messages (None results in prefix "Item")
       """
+      super(RegexMatchList, self).__init__()
       self.prefix = "Item"
       if prefix is not None: self.prefix = prefix
       self.valuesRegex = valuesRegex
@@ -645,10 +639,11 @@ class DirectedGraph(object):
       @param other: Other object to compare to.
       @return: -1/0/1 depending on whether self is C{<}, C{=} or C{>} other.
       """
+      # pylint: disable-msg=W0212
       if other is None:
          return 1
-      if self._name != other._name:
-         if self._name < other._name:
+      if self.name != other.name:
+         if self.name < other.name:
             return -1
          else:
             return 1
@@ -805,10 +800,13 @@ class PathResolverSingleton(object):
 
    class _Helper:
       """Helper class to provide a singleton factory method."""
+      def __init__(self):
+         pass
       def __call__(self, *args, **kw):
+         # pylint: disable-msg=W0212,R0201
          if PathResolverSingleton._instance is None:
-            object = PathResolverSingleton()
-            PathResolverSingleton._instance = object
+            obj = PathResolverSingleton()
+            PathResolverSingleton._instance = obj
          return PathResolverSingleton._instance
     
    getInstance = _Helper()    # Method that callers will use to get an instance
@@ -848,99 +846,22 @@ class PathResolverSingleton(object):
 # Pipe class definition
 ########################################################################
 
-if _PIPE_IMPLEMENTATION == "subprocess.Popen":
+class Pipe(Popen):
+   """
+   Specialized pipe class for use by C{executeCommand}.
 
-   from subprocess import STDOUT, PIPE
-
-   class Pipe(Popen):
-      """
-      Specialized pipe class for use by C{executeCommand}.
-
-      The L{executeCommand} function needs a specialized way of interacting
-      with a pipe.  First, C{executeCommand} only reads from the pipe, and
-      never writes to it.  Second, C{executeCommand} needs a way to discard all
-      output written to C{stderr}, as a means of simulating the shell
-      C{2>/dev/null} construct.  
-
-      All of this functionality is provided (in Python 2.4 or later) by the
-      C{subprocess.Popen} class, so when that class is available, we'll use it.
-      Otherwise, there's another implementation based on C{popen2.Popen4},
-      which unfortunately only works on UNIX platforms.
-      """
-      def __init__(self, cmd, bufsize=-1, ignoreStderr=False):
-         stderr = STDOUT
-         if ignoreStderr:
-            devnull = nullDevice()
-            stderr = os.open(devnull, os.O_RDWR) 
-         Popen.__init__(self, shell=False, args=cmd, bufsize=bufsize, stdin=None, stdout=PIPE, stderr=stderr)
-         self.fromchild = self.stdout  # for compatibility with original interface based on popen2.Popen4
-
-else: # _PIPE_IMPLEMENTATION == "popen2.Popen4" 
-
-   from popen2 import _cleanup, _active
-
-   class Pipe(Popen4):
-      """
-      Specialized pipe class for use by C{executeCommand}.
-
-      The L{executeCommand} function needs a specialized way of interacting with a
-      pipe that isn't satisfied by the standard C{Popen3} and C{Popen4} classes in
-      C{popen2}.  First, C{executeCommand} only reads from the pipe, and never
-      writes to it.  Second, C{executeCommand} needs a way to discard all output
-      written to C{stderr}, as a means of simulating the shell C{2>/dev/null}
-      construct.  
-
-      This class inherits from C{Popen4}.  If the C{ignoreStderr} flag is passed in
-      as C{False}, then the standard C{Popen4} constructor will be called and
-      C{stdout} and C{stderr} will be intermingled in the output.  
-
-      Otherwise, we'll call a custom version of the constructor which was
-      basically stolen from the real constructor in C{python2.3/Lib/popen2.py}.
-      This custom constructor will redirect the C{stderr} file descriptor to
-      C{/dev/null}.  I've done this based on a suggestion from Donn Cave on
-      comp.lang.python.
-
-      In either case, the C{tochild} file object is always closed before returning
-      from the constructor, since it is never needed by C{executeCommand}.
-
-      I really wish there were a prettier way to do this.  Unfortunately, I
-      need access to the guts of the constructor implementation because of the
-      way the pipe process is forked, etc.  It doesn't work to just call the
-      superclass constructor and then modify a few things afterwards.  Even
-      worse, I have to access private C{popen2} module members C{_cleanup} and
-      C{_active} in order to duplicate the implementation.  
-
-      Hopefully this whole thing will continue to work properly.  At least we
-      can use the other L{subprocess.Popen}-based implementation when that
-      class is available.
-      
-      @copyright: Some of this code, prior to customization, was originally part
-      of the Python 2.3 codebase.  Python code is copyright (c) 2001, 2002 Python
-      Software Foundation; All Rights Reserved.
-      """
-      
-      def __init__(self, cmd, bufsize=-1, ignoreStderr=False):
-         if not ignoreStderr:
-            Popen4.__init__(self, cmd, bufsize)
-         else:
-            _cleanup()
-            p2cread, p2cwrite = os.pipe()
-            c2pread, c2pwrite = os.pipe()
-            self.pid = os.fork()
-            if self.pid == 0: # Child
-               os.dup2(p2cread, 0)
-               os.dup2(c2pwrite, 1)
-               devnull = nullDevice()
-               null = os.open(devnull, os.O_RDWR)
-               os.dup2(null, 2)
-               os.close(null)
-               self._run_child(cmd)
-            os.close(p2cread)
-            self.tochild = os.fdopen(p2cwrite, 'w', bufsize)
-            os.close(c2pwrite)
-            self.fromchild = os.fdopen(c2pread, 'r', bufsize)
-            _active.append(self)
-         self.tochild.close()       # we'll never write to it, and this way we don't confuse anything.
+   The L{executeCommand} function needs a specialized way of interacting
+   with a pipe.  First, C{executeCommand} only reads from the pipe, and
+   never writes to it.  Second, C{executeCommand} needs a way to discard all
+   output written to C{stderr}, as a means of simulating the shell
+   C{2>/dev/null} construct.  
+   """
+   def __init__(self, cmd, bufsize=-1, ignoreStderr=False):
+      stderr = STDOUT
+      if ignoreStderr:
+         devnull = nullDevice()
+         stderr = os.open(devnull, os.O_RDWR) 
+      Popen.__init__(self, shell=False, args=cmd, bufsize=bufsize, stdin=None, stdout=PIPE, stderr=stderr)
 
 
 ########################################################################
@@ -957,6 +878,7 @@ class Diagnostics(object):
 
    @sort: __init__, __repr__, __str__
    """
+   # pylint: disable-msg=R0201
 
    def __init__(self):
       """
@@ -987,7 +909,7 @@ class Diagnostics(object):
       values['encoding'] = self.encoding
       values['locale'] = self.locale
       values['timestamp'] = self.timestamp
-      return values;
+      return values
 
    def printDiagnostics(self, fd=sys.stdout, prefix=""):
       """
@@ -1029,6 +951,7 @@ class Diagnostics(object):
          lines.append(line)
       return lines
 
+   @staticmethod
    def _getMaxLength(values):
       """
       Get the maximum length from among a list of strings.
@@ -1038,7 +961,6 @@ class Diagnostics(object):
          if len(value) > tmax:
             tmax = len(value)
       return tmax
-   _getMaxLength = staticmethod(_getMaxLength)
 
    def _getVersion(self):
       """
@@ -1065,10 +987,10 @@ class Diagnostics(object):
       """
       try:
          if sys.platform.startswith("win"):
-            WINDOWS_PLATFORMS = [ "Windows 3.1", "Windows 95/98/ME", "Windows NT/2000/XP", "Windows CE", ]
-            wininfo = sys.getwindowsversion()
+            windowsPlatforms = [ "Windows 3.1", "Windows 95/98/ME", "Windows NT/2000/XP", "Windows CE", ]
+            wininfo = sys.getwindowsversion()  # pylint: disable-msg=E1101
             winversion = "%d.%d.%d" % (wininfo[0], wininfo[1], wininfo[2])
-            winplatform = WINDOWS_PLATFORMS[wininfo[3]]
+            winplatform = windowsPlatforms[wininfo[3]]
             wintext = wininfo[4]  # i.e. "Service Pack 2"
             return "%s (%s %s %s)" % (sys.platform, winplatform, winversion, wintext)
          else:
@@ -1119,7 +1041,10 @@ class Diagnostics(object):
 def sortDict(d):
    """
    Returns the keys of the dictionary sorted by value.
-   There are cuter ways to do this in Python 2.4, but we're compatible with 2.3.
+
+   There are cuter ways to do this in Python 2.4, but we were originally
+   attempting to stay compatible with Python 2.3.
+
    @param d: Dictionary to operate on
    @return: List of dictionary keys sorted in order by dictionary value.
    """
@@ -1298,7 +1223,7 @@ def getFunctionReference(module, function):
    if module is not None and module != "":
       parts = module.split(".")
    if function is not None and function != "":
-      parts.append(function);
+      parts.append(function)
    copy = parts[:]
    while copy:
       try:
@@ -1339,13 +1264,12 @@ def getUidGid(user, group):
       try:
          uid = pwd.getpwnam(user)[2]
          gid = grp.getgrnam(group)[2]
-         logger.debug("Translated [%s:%s] into [%d:%d]." % (user, group, uid, gid))
          return (uid, gid)
       except Exception, e:
          logger.debug("Error looking up uid and gid for [%s:%s]: %s" % (user, group, e))
          raise ValueError("Unable to lookup up uid and gid for passed in user/group.")
    else:
-      return (0,0)
+      return (0, 0)
 
 
 #############################
@@ -1357,7 +1281,8 @@ def changeOwnership(path, user, group):
    Changes ownership of path to match the user and group.
 
    This is a no-op if user/group functionality is not available on the
-   platform, or if the either passed-in user or group is C{None}.
+   platform, or if the either passed-in user or group is C{None}.  Further, we
+   won't even try to do it unless running as root, since it's unlikely to work.
 
    @param path: Path whose ownership to change.
    @param user: User which owns file.
@@ -1366,7 +1291,7 @@ def changeOwnership(path, user, group):
    if _UID_GID_AVAILABLE:
       if user is None or group is None:
          logger.debug("User or group is None, so not attempting to change owner on [%s]." % path)
-      elif os.getuid() != 0:
+      elif not isRunningAsRoot():
          logger.debug("Not root, so not attempting to change owner on [%s]." % path)
       else:
          try:
@@ -1376,6 +1301,17 @@ def changeOwnership(path, user, group):
             logger.error("Error changing ownership of [%s]: %s" % (path, e))
 
 
+#############################
+# isRunningAsRoot() function
+#############################
+
+def isRunningAsRoot():
+   """
+   Indicates whether the program is running as the root user.
+   """
+   return os.getuid() == 0
+
+
 ##############################
 # splitCommandLine() function
 ##############################
@@ -1543,7 +1479,7 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotL
          # The problem appears to be that we sometimes get a bad stderr file descriptor.
          pipe = Pipe(fields, ignoreStderr=ignoreStderr)
       while True:
-         line = pipe.fromchild.readline()
+         line = pipe.stdout.readline()
          if not line: break
          if returnOutput: output.append(line)
          if outputFile is not None: outputFile.write(line)
@@ -1576,7 +1512,7 @@ def executeCommand(command, args, returnOutput=False, ignoreStderr=False, doNotL
 # calculateFileAge() function
 ##############################
 
-def calculateFileAge(file):
+def calculateFileAge(path):
    """
    Calculates the age (in days) of a file.
 
@@ -1586,13 +1522,13 @@ def calculateFileAge(file):
    Technically, we only intend this function to work with files, but it will
    probably work with anything on the filesystem.
 
-   @param file: Path to a file on disk.
+   @param path: Path to a file on disk.
 
    @return: Age of the file in days (possibly fractional).
    @raise OSError: If the file doesn't exist.
    """
    currentTime = int(time.time())
-   fileStats = os.stat(file)
+   fileStats = os.stat(path)
    lastUse = max(fileStats.st_atime, fileStats.st_mtime)  # "most recent" is "largest" 
    ageInSeconds = currentTime - lastUse
    ageInDays = ageInSeconds / SECONDS_PER_DAY
@@ -1841,20 +1777,8 @@ def nullDevice():
 
    The null device is something like C{/dev/null} on a UNIX system.  The name
    varies on other platforms.
-
-   In Python 2.4 and better, we can use C{os.devnull}.  Since we want to be
-   portable to python 2.3, getting the value in earlier versions of Python
-   takes some screwing around.  Basically, this function will only work on
-   either UNIX-like systems (the default) or Windows.
    """
-   try:
-      return os.devnull
-   except AttributeError: 
-      import platform
-      if platform.platform().startswith("Windows"):
-         return "NUL"
-      else:
-         return "/dev/null"
+   return os.devnull
 
 
 ##############################
@@ -2012,3 +1936,56 @@ def dereferenceLink(path, absolute=True):
       return result
    return path
 
+
+#########################
+# checkUnique() function
+#########################
+
+def checkUnique(prefix, values):
+   """
+   Checks that all values are unique.
+
+   The values list is checked for duplicate values.  If there are
+   duplicates, an exception is thrown.  All duplicate values are listed in
+   the exception.
+
+   @param prefix: Prefix to use in the thrown exception
+   @param values: List of values to check
+
+   @raise ValueError: If there are duplicates in the list
+   """
+   values.sort()
+   duplicates = []
+   for i in range(1, len(values)):
+      if values[i-1] == values[i]:
+         duplicates.append(values[i])
+   if duplicates:
+      raise ValueError("%s %s" % (prefix, duplicates))
+
+
+#######################################
+# parseCommaSeparatedString() function
+#######################################
+
+def parseCommaSeparatedString(commaString):
+   """
+   Parses a list of values out of a comma-separated string.
+
+   The items in the list are split by comma, and then have whitespace
+   stripped.  As a special case, if C{commaString} is C{None}, then C{None}
+   will be returned.
+
+   @param commaString: List of values in comma-separated string format.
+   @return: Values from commaString split into a list, or C{None}.
+   """
+   if commaString is None:
+      return None
+   else:
+      pass1 = commaString.split(",")
+      pass2 = []
+      for item in pass1:
+         item = item.strip()
+         if len(item) > 0:
+            pass2.append(item)
+      return pass2
+
