@@ -8,7 +8,7 @@
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
-# Copyright (c) 2007-2008 Kenneth J. Pronovici.
+# Copyright (c) 2007-2008,2010 Kenneth J. Pronovici.
 # All rights reserved.
 #
 # This program is free software; you can redistribute it and/or
@@ -25,9 +25,9 @@
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
-# Language : Python (>= 2.3)
+# Language : Python (>= 2.5)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: dvdwriter.py 972 2010-05-22 16:51:20Z pronovic $
+# Revision : $Id: dvdwriter.py 1006 2010-07-07 21:03:57Z pronovic $
 # Purpose  : Provides functionality related to DVD writer devices.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -60,7 +60,6 @@ import tempfile
 import time
 
 # Cedar Backup modules
-from CedarBackup2.filesystem import BackupFileList
 from CedarBackup2.writers.util import IsoImage
 from CedarBackup2.util import resolveCommand, executeCommand
 from CedarBackup2.util import convertSize, displayBytes, encodePath
@@ -361,7 +360,7 @@ class DvdWriter(object):
    # Constructor
    ##############
 
-   def __init__(self, device, scsiId=None, driveSpeed=None, 
+   def __init__(self, device, scsiId=None, driveSpeed=None,
                 mediaType=MEDIA_DVDPLUSRW, noEject=False, 
                 refreshMediaDelay=0, unittest=False):
       """
@@ -476,7 +475,7 @@ class DvdWriter(object):
 
    device = property(_getDevice, None, None, doc="Filesystem device name for this writer.")
    scsiId = property(_getScsiId, None, None, doc="SCSI id for the device (saved for reference only).")
-   hardwareId = property(_getHardwareId, None, None, doc="Hardware id for this writer (always the device path).");
+   hardwareId = property(_getHardwareId, None, None, doc="Hardware id for this writer (always the device path).")
    driveSpeed = property(_getDriveSpeed, None, None, doc="Speed at which the drive writes.")
    media = property(_getMedia, None, None, doc="Definition of media that is expected to be in the device.")
    deviceHasTray = property(_getDeviceHasTray, None, None, doc="Indicates whether the device has a media tray.")
@@ -748,6 +747,7 @@ class DvdWriter(object):
          raise IOError("Error (%d) executing command to write disc." % result)
       self.refreshMedia()
 
+   @staticmethod
    def _getEstimatedImageSize(entries):
       """
       Gets the estimated size of a set of image entries.
@@ -774,7 +774,6 @@ class DvdWriter(object):
          image.addEntry(path, entries[path], override=False, contentsOnly=True)
       estimatedSize = image.getEstimatedSize() + fudgeFactor
       return estimatedSize
-   _getEstimatedImageSize = staticmethod(_getEstimatedImageSize)
 
    def _retrieveSectorsUsed(self):
       """
@@ -809,6 +808,7 @@ class DvdWriter(object):
                os.rmdir(tempdir)
             except: pass
 
+   @staticmethod
    def _parseSectorsUsed(output):
       """
       Parse sectors used information out of C{growisofs} output.
@@ -839,8 +839,8 @@ class DvdWriter(object):
                   raise ValueError("Unable to parse sectors used out of growisofs output.")
       logger.warn("Unable to read disc (might not be initialized); returning zero sectors used.")
       return 0.0
-   _parseSectorsUsed = staticmethod(_parseSectorsUsed)
 
+   @staticmethod
    def _searchForOverburn(output):
       """
       Search for an "overburn" error message in C{growisofs} output.
@@ -875,8 +875,8 @@ class DvdWriter(object):
             except ValueError: 
                logger.error("Image does not fit in available capacity (no useful capacity info available).")
             raise IOError("Media does not contain enough capacity to store image.")
-   _searchForOverburn = staticmethod(_searchForOverburn)
          
+   @staticmethod
    def _buildWriteArgs(newDisc, hardwareId, driveSpeed, imagePath, entries, mediaLabel=None, dryRun=False):
       """
       Builds a list of arguments to be passed to a C{growisofs} command.
@@ -942,5 +942,4 @@ class DvdWriter(object):
             else:
                args.append("%s/=%s" % (entries[key].strip("/"), key))
       return args
-   _buildWriteArgs = staticmethod(_buildWriteArgs)
 
